From 19b2182a747675ac0f509b13a9c86908edaa0385 Mon Sep 17 00:00:00 2001
From: Peter Smith <peter.b.smith@fujitsu.com>
Date: Wed, 19 Oct 2022 12:58:50 +1100
Subject: [PATCH v2] clarify behavior of specifying a parameter with no value

Modified docs for
- CREATE/ALTER PUBLICATION
- CREATE/ALTER SUBSCRIPTION
---
 doc/src/sgml/ref/alter_publication.sgml   |  3 +++
 doc/src/sgml/ref/alter_subscription.sgml  | 12 +++++++++---
 doc/src/sgml/ref/create_publication.sgml  | 11 +++++++++--
 doc/src/sgml/ref/create_subscription.sgml |  5 +++++
 4 files changed, 26 insertions(+), 5 deletions(-)

diff --git a/doc/src/sgml/ref/alter_publication.sgml b/doc/src/sgml/ref/alter_publication.sgml
index c84b11f..2b4eb1f 100644
--- a/doc/src/sgml/ref/alter_publication.sgml
+++ b/doc/src/sgml/ref/alter_publication.sgml
@@ -148,6 +148,9 @@ ALTER PUBLICATION <replaceable class="parameter">name</replaceable> RENAME TO <r
      <para>
       This clause alters publication parameters originally set by
       <xref linkend="sql-createpublication"/>.  See there for more information.
+      For <type>boolean</type> parameters the
+      <replaceable class="parameter">value</replaceable> can be omitted, which
+      is equivalent to specifying <literal>TRUE</literal>.
      </para>
     </listitem>
    </varlistentry>
diff --git a/doc/src/sgml/ref/alter_subscription.sgml b/doc/src/sgml/ref/alter_subscription.sgml
index 1e8d720..759b7a3 100644
--- a/doc/src/sgml/ref/alter_subscription.sgml
+++ b/doc/src/sgml/ref/alter_subscription.sgml
@@ -132,7 +132,9 @@ ALTER SUBSCRIPTION <replaceable class="parameter">name</replaceable> RENAME TO <
          <para>
           When false, the command will not try to refresh table information.
           <literal>REFRESH PUBLICATION</literal> should then be executed separately.
-          The default is <literal>true</literal>.
+          The default is <literal>true</literal>. The
+          <replaceable class="parameter">value</replaceable> can be omitted,
+          which is equivalent to specifying <literal>TRUE</literal>.
          </para>
         </listitem>
        </varlistentry>
@@ -166,7 +168,9 @@ ALTER SUBSCRIPTION <replaceable class="parameter">name</replaceable> RENAME TO <
          <para>
           Specifies whether to copy pre-existing data in the publications
           that are being subscribed to when the replication starts.
-          The default is <literal>true</literal>.
+          The default is <literal>true</literal>. The
+          <replaceable class="parameter">value</replaceable> can be omitted,
+          which is equivalent to specifying <literal>TRUE</literal>.
          </para>
          <para>
           Previously subscribed tables are not copied, even if a table's row
@@ -214,7 +218,9 @@ ALTER SUBSCRIPTION <replaceable class="parameter">name</replaceable> RENAME TO <
       <literal>synchronous_commit</literal>,
       <literal>binary</literal>, <literal>streaming</literal>,
       <literal>disable_on_error</literal>, and
-      <literal>origin</literal>.
+      <literal>origin</literal>. For <type>boolean</type> parameters the
+      <replaceable class="parameter">value</replaceable> can be omitted, which
+      is equivalent to specifying <literal>TRUE</literal>.
      </para>
     </listitem>
    </varlistentry>
diff --git a/doc/src/sgml/ref/create_publication.sgml b/doc/src/sgml/ref/create_publication.sgml
index e229384..d8015af 100644
--- a/doc/src/sgml/ref/create_publication.sgml
+++ b/doc/src/sgml/ref/create_publication.sgml
@@ -162,8 +162,15 @@ CREATE PUBLICATION <replaceable class="parameter">name</replaceable>
     <term><literal>WITH ( <replaceable class="parameter">publication_parameter</replaceable> [= <replaceable class="parameter">value</replaceable>] [, ... ] )</literal></term>
     <listitem>
      <para>
-      This clause specifies optional parameters for a publication.  The
-      following parameters are supported:
+      This clause specifies optional parameters for a publication.
+     </para>
+     <para>
+      For <type>boolean</type> parameters the
+      <replaceable class="parameter">value</replaceable> can be omitted, which
+      is equivalent to specifying <literal>TRUE</literal>.
+     </para>
+     <para>
+      The following parameters are supported:
 
       <variablelist>
        <varlistentry>
diff --git a/doc/src/sgml/ref/create_subscription.sgml b/doc/src/sgml/ref/create_subscription.sgml
index f9a1776..9406aa9 100644
--- a/doc/src/sgml/ref/create_subscription.sgml
+++ b/doc/src/sgml/ref/create_subscription.sgml
@@ -96,6 +96,11 @@ CREATE SUBSCRIPTION <replaceable class="parameter">subscription_name</replaceabl
      <para>
       This clause specifies optional parameters for a subscription.
      </para>
+     <para>
+      For <type>boolean</type> parameters the
+      <replaceable class="parameter">value</replaceable> can be omitted, which
+      is equivalent to specifying <literal>TRUE</literal>.
+     </para>
 
      <para>
       The following parameters control what happens during subscription creation:
-- 
1.8.3.1

